# Un programa para ordenar las soluciones
# a un problema multiobjetivo según la
# dominancia de Pareto
#
# Fraga 1.10.2019
# Fraga 17.05.2023
# Adecuación para PYMOO

# Entrada:
# Leemos todas las soluciones: 
# valores de las funciones objetivo y cada línea del
# archivo de entrada

# Salida:
# El conjunto de soluciones no dominadas
#
# Necesitamos:
# el nombre del archivo,
# número de objetivos
# número de restricciones (?)
#
# Leemos el archivo una sola vez para calcular
# el número de soluciones
import sys
import numpy as np
import dominancia

n = len( sys.argv )
if n != 7 :
	print( "Args: arch_var1 arch_obj1 arch_const1 arch_var2 arch_obj2 arch_const2" )
	sys.exit( 1 )

X1 = np.loadtxt( sys.argv[1] )
# print( X1.shape )
O1 = np.loadtxt( sys.argv[2] )
C1 = np.loadtxt( sys.argv[3] )

X2 = np.loadtxt( sys.argv[4] )
O2 = np.loadtxt( sys.argv[5] )
C2 = np.loadtxt( sys.argv[6] )

X = np.vstack( [X1, X2] )
O = np.vstack( [O1, O2] )
C = np.vstack( [C1, C2] )


n, m = O.shape 
# Tenemos n soluciones
#
soluciones = [False]*n

i=0
while i < n :
	j = i+1
	while j < n :
		d = dominancia.dominancia( m, O[i], O[j] )
		# print i, j, d
		if d == 1 :    # V[i] domina
			soluciones[j] = True
		elif d == -1 : # V[j] domina
			soluciones[i] = True
		j += 1
	i += 1

X = np.delete( X, soluciones, axis=0 )
O = np.delete( O, soluciones, axis=0 )
C = np.delete( C, soluciones, axis=0 )


np.savetxt( "vars.txt", X )
np.savetxt( "objs.txt", O )
np.savetxt( "const.txt", C )
